import java.io.*;
import java.net.Socket;
import java.security.KeyStore;
import java.security.MessageDigest;
import javax.net.ssl.*;

public class QualsClient
    implements QualsConstants
{
    public QualsClient(String s, int i) {
        tsp = null;
        ksf = "cks";
        tsf = "cts";
        serverAddress = s;
        serverPort = i;
    }

    public void loadKeyStore(InputStream inputstream) {
        try {
            mks = KeyStore.getInstance("JKS");
            mks.load(inputstream, ksp);
        }
        catch(Exception exception) { }
    }

    public void loadTrustStore(InputStream inputstream) {
        try
        {
            mts = KeyStore.getInstance("JKS");
            mts.load(inputstream, tsp);
        }
        catch(Exception exception) { }
    }

    public void initSSL() {
        try
        {
            ClassLoader classloader = getClass().getClassLoader();
            tsp = ksp;
            loadKeyStore(classloader.getResourceAsStream(ksf));
            loadTrustStore(classloader.getResourceAsStream(tsf));
            KeyManagerFactory keymanagerfactory = KeyManagerFactory.getInstance("SunX509");
            keymanagerfactory.init(mks, ksp);
            javax.net.ssl.KeyManager akeymanager[] = keymanagerfactory.getKeyManagers();
            TrustManagerFactory trustmanagerfactory = TrustManagerFactory.getInstance("PKIX");
            trustmanagerfactory.init(mts);
            javax.net.ssl.TrustManager atrustmanager[] = trustmanagerfactory.getTrustManagers();
            SSLContext sslcontext = SSLContext.getInstance("SSL");
            sslcontext.init(akeymanager, atrustmanager, null);
            sslsf = sslcontext.getSocketFactory();
        }
        catch(Exception exception) { }
    }

    public synchronized QualsConnection connect() {
        do
            try
            {
                Socket socket = new Socket(serverAddress, serverPort);
                return new QualsConnection(socket);
            }
            catch(Exception exception) { }
        while(true);
    }

    protected static byte[] hmac(byte abyte0[], byte abyte1[]) {
        MessageDigest messagedigest = null;
        try
        {
            messagedigest = MessageDigest.getInstance("MD5");
        }
        catch(Exception exception) { }
        if(abyte1.length > 64)
        {
            messagedigest.reset();
            abyte1 = messagedigest.digest(abyte1);
        }
        byte abyte2[] = new byte[64];
        System.arraycopy(abyte1, 0, abyte2, 0, abyte1.length);
        byte abyte3[] = (byte[])abyte2.clone();
        for(int i = 0; i < abyte2.length; i++)
        {
            abyte2[i] ^= 0x36;
            abyte3[i] ^= 0x5c;
        }

        messagedigest.reset();
        messagedigest.update(abyte2);
        byte abyte4[] = messagedigest.digest(abyte0);
        messagedigest.reset();
        messagedigest.update(abyte3);
        return messagedigest.digest(abyte4);
    }

    public synchronized boolean relogin()
    {
        System.out.println("Attempting reconnect...");
        boolean flag = false;
        QualsConnection qualsconnection = null;
        try
        {
            qualsconnection = connect();
            qualsconnection.ps.println("login");
            byte abyte0[] = new byte[32];
            qualsconnection.is.read(abyte0);
            qualsconnection.ps.println(userName);
            byte abyte1[] = hmac(abyte0, password.getBytes());
            qualsconnection.ps.write(abyte1);
            String s = qualsconnection.readLine();
            if (!"205".equals(s)) { System.out.println("ReLogin error"); return false; }
            cookie = qualsconnection.readLine();
            if (cookie == null) { System.out.println("ReLogin error"); return false; }
            scoreboard = qualsconnection.readLine();
            scorelist = qualsconnection.readLine();
            teamname = qualsconnection.readLine();
            score = qualsconnection.readLine();
            question = qualsconnection.readLine();
            if (question == null) { question=""; }
            flag = true;
        }
        catch(Exception exception1)
        {
            try
            {
                if(qualsconnection != null)
                {
                    qualsconnection.s.close();
                    qualsconnection = null;
                }
            }
            catch(Exception exception2) { }
        }
        return flag;
    }

    public synchronized boolean login(String s, String s1)
    {
        QualsConnection qualsconnection;
        boolean flag;
        qualsconnection = null;
        flag = false;
        System.out.println("Logging in");
        try {
            qualsconnection = connect();
            qualsconnection.ps.println("login");
            byte abyte0[] = new byte[32];
            qualsconnection.is.read(abyte0);
            qualsconnection.ps.println(s);
            byte abyte1[] = hmac(abyte0, s1.getBytes());
            qualsconnection.ps.write(abyte1);
            String s2 = qualsconnection.readLine();
            if("205".equals(s2)) {
                cookie = qualsconnection.readLine();
                if(cookie != null) {
                    userName = s;
                    password = s1;
                    scoreboard = qualsconnection.readLine();
                    scorelist = qualsconnection.readLine();
                    teamname = qualsconnection.readLine();
                    score = qualsconnection.readLine();
                    String question = qualsconnection.readLine();
                    if(question == null) { question=""; }
                    flag = true;
                }
            }
        }
        catch(Exception exception1) {
            try {
                if(qualsconnection != null) {
                    qualsconnection.s.close();
                    qualsconnection = null;
                }
            }
            catch(Exception exception2) { }
        }
        return flag;
    }

    public synchronized boolean forgotPass(String s)
    {
        QualsConnection qualsconnection;
        boolean flag;
        qualsconnection = null;
        flag = false;
        try {
            qualsconnection = connect();
            qualsconnection.ps.println("dumbass");
            qualsconnection.ps.println(s);
            String s1 = qualsconnection.readLine();
            flag = "200".equals(s1);
        }
        catch(Exception exception1) {
            try {
                if(qualsconnection != null) {
                    qualsconnection.s.close();
                    qualsconnection = null;
                }
            }
            catch(Exception exception2) { }
        }
        return flag;
    }

    public synchronized void logout()
    {
        QualsConnection qualsconnection;
        qualsconnection = null;
        try {
            qualsconnection = connect();
            qualsconnection.ps.println("logout");
            qualsconnection.ps.println(cookie);
            cookie = null;
        }
        catch(Exception exception1) {
            try {
                if(qualsconnection != null) {
                    qualsconnection.s.close();
                    qualsconnection = null;
                }
            }
            catch(Exception exception2) { }
        }
        cookie = null;
        userName = null;
        password = null;
        System.out.println("Logged out");
        return;
    }

    public synchronized boolean update()
    {
        boolean flag;
        QualsConnection qualsconnection;
        if (cookie == null) return false;
        flag = false;
        qualsconnection = null;
        try {
            qualsconnection = connect();
            qualsconnection.ps.println("update");
            qualsconnection.ps.println(cookie);
            String s = qualsconnection.readLine();
            if("401".equals(s)) relogin();
            if("205".equals(s)) {
                scoreboard = qualsconnection.readLine();
                scorelist = qualsconnection.readLine();
                score = qualsconnection.readLine();
                flag = true;
            }
        }
        catch(Exception exception1) {
            try {
                if(qualsconnection != null) {
                    qualsconnection.s.close();
                    qualsconnection = null;
                }
            }
            catch(Exception exception2) { }
        }
        return flag;
    }

    public String choose(int i, int j)
    {
        String s;
        QualsConnection qualsconnection;
        if(cookie == null) return null;
        s = null;
        qualsconnection = null;
        try {
            qualsconnection = connect();
            qualsconnection.ps.println("choice");
            qualsconnection.ps.println(cookie);
            qualsconnection.ps.println((new StringBuilder()).append("").append(i).toString());
            qualsconnection.ps.println((new StringBuilder()).append("").append(j).toString());
            String s1 = qualsconnection.readLine();
            if ("401".equals(s1)) relogin();
            else if("205".equals(s1)) {
                s = qualsconnection.readLine();
                scoreboard = qualsconnection.readLine();
            }
        }
        catch(Exception exception1) {
            try {
                if(qualsconnection != null) {
                    qualsconnection.s.close();
                    qualsconnection = null;
                }
            }
            catch(Exception exception2) { }
        }
        return s;
    }

    public int answer(int i, int j, String s)
    {
        byte byte0;
        QualsConnection qualsconnection;
        if(cookie == null) return 3;
        byte0 = 0;
        qualsconnection = null;
        try {
            qualsconnection = connect();
            qualsconnection.ps.println("answer");
            qualsconnection.ps.println(cookie);
            qualsconnection.ps.println((new StringBuilder()).append("").append(i).toString());
            qualsconnection.ps.println((new StringBuilder()).append("").append(j).toString());
            qualsconnection.ps.println(s);
            String s1 = qualsconnection.readLine();
            if ("401".equals(s1)) byte0 = 3;
            else if ("205".equals(s1)) {
                scoreboard = qualsconnection.readLine();
                scorelist = qualsconnection.readLine();
                score = qualsconnection.readLine();
                byte0 = 1;
            }
            else if("403".equals(s1)) byte0 = 6;
        }
        catch(Exception exception1) {
            try {
                if(qualsconnection != null) {
                    qualsconnection.s.close();
                    qualsconnection = null;
                }
            }
            catch(Exception exception2) { }
        }
        return byte0;
    }

    public static final int MD5_LEN = 16;
    public static final int CHALLENGE_LEN = 32;
    public char ksp[] = {
        'd', 'e', 'f', 'c', 'o', 'n', '1', '7', 'q', 'u', 
        'a', 'l', 's'
    };
    public char tsp[];
    public KeyStore mks;
    public String ksf;
    public KeyStore mts;
    public String tsf;
    public SSLSocketFactory sslsf;
    public int serverPort;
    public String serverAddress;
    public String cookie;
    public String userName;
    public String password;
    public String scoreboard;
    public String scorelist;
    public String teamname;
    public String score;
    public String question;
    public static final boolean useSSL = false;
}
